import { VError, Options as VErrorOptions } from 'verror';
import { ParseElement } from './conditions_types';
/**
 * Thrown when insert() is called with a specified _id
 * that already exists
 */
export declare class ConflictException extends VError {
    constructor(message: string, id: string);
}
/**
 * Thrown when an `_id` value is specified that is not
 * valid (_id values must be a string).
 */
export declare class InvalidIdException extends VError {
    constructor(id: any);
}
/**
 * Thrown when the child object to be inserted has a missing or invalid
 * parent key value.
 */
export declare class InvalidParentIdException extends VError {
    constructor(parentId: any, collectionName: string, parentCollectionName: string);
}
/**
 * Thrown when the collection specified cannot be found in the context, or
 * isn't of the expected type (root or child) for the called API.
 */
export declare class CollectionNotFoundException extends VError {
    constructor(collection: string);
}
/**
 * Thrown when the index is not found for the provided query.
 */
export declare class IndexNotFoundException extends VError {
    constructor(index: string);
}
/**
 * Thrown during context construction to indicate a configuration
 * issue in the specified collections, access patterns or layouts.
 */
export declare class ConfigurationException extends VError {
    constructor(message: string, options?: VErrorOptions);
}
/**
 * Thrown on invalid field values that are provided during
 * persistence (insert/update/replace).
 */
export declare class InvalidIndexedFieldValueException extends VError {
    constructor(message: string, { collection, keyPath }: {
        collection: string;
        keyPath: string[];
    });
}
/**
 * Thrown on an invalidly specified query provided to a
 * `find()` operation.
 */
export declare class InvalidQueryException extends VError {
    constructor(message: string, { collection, query }: {
        collection: string;
        query: Record<string, any>;
    });
}
/**
 * Thrown when the updates provided to an `update()` operation
 * are invalid.
 */
export declare class InvalidUpdatesException extends VError {
    constructor(message: string);
}
/**
 * Thrown when the update values provided in an `update()` operation
 * are invalid (e.g. `undefined`)
 */
export declare class InvalidUpdateValueException extends VError {
    constructor(path: string, message: string);
}
/**
 * Throw when the find descriptor for a transactFindByIds or
 * batchFindByIds is invalid.
 */
export declare class InvalidFindDescriptorException extends VError {
    constructor(message: string);
}
/**
 * Thrown when something from DynamoDB doesn't match
 * the context configuration during response processing
 */
export declare class InternalProcessingException extends VError {
    constructor(message: string);
}
/**
 * Thrown when there is a problem with the expression given
 * as a `FilterExpression` or `ConditionExpression`.
 */
export declare class InvalidCompositeConditionException extends VError {
    constructor(message: string, parsePath: ParseElement[]);
}
/**
 * An exception thrown when a bad set of
 * [[BatchReplaceDeleteDescriptor]] is given to
 * [[batchReplaceDelete]]
 */
export declare class InvalidBatchReplaceDeleteDescriptorException extends VError {
    constructor(message: string, info?: Record<string, any>);
}
export declare class InvalidRangeOperatorException extends VError {
    constructor(message: string, operator: string);
}
