import DynamoDB from 'aws-sdk/clients/dynamodb';
import { Collection } from '../base/collection';
import { DynaglueContext } from './context_types';
/**
 * An opaquely defined type
 */
export declare type Opaque<K, T> = T & {
    __TYPE__: K;
};
/**
 * A dynaglue context. Use [[createContext]] to instantiate.
 *
 * The internal layout of this type may change over time.
 */
export declare type Context = Opaque<'DynaglueContext', DynaglueContext>;
/**
 * Create a context object, with layouts and access patterns for
 * storing and retrieving data.
 *
 * @param dynamodb dynamodb instance, initialised with correct access key and region
 * @param collections a list of collection definitions to use with this context
 * @returns a context object
 *  @throws {ConfigurationException} when there is a configuration issue in the given collections
 */
export declare function createContext(dynamodb: DynamoDB, collections: Collection[]): Context;
