import { Context } from '../context';
import { DocumentWithId } from '../base/common';
/**
 * The collection and ID of a root or child
 * item to retrieve with #transactFindByIds
 */
export declare type BatchFindByIdDescriptor = {
    /** The collection containing the item */
    collection: string;
    id: string;
    parentId?: string;
};
/**
 * The response to a [[batchFindByIds]] request. The
 * retrieved documents are stored in a map, organised by
 * collection name.
 *
 * Any unprocessed request keys are included in the
 * unprocessedDescriptors list. You will need to submit
 * another request to obtain these.
 */
export declare type BatchFindByIdsResponse = {
    documentsByCollection: {
        [collection: string]: DocumentWithId[];
    };
    unprocessedDescriptors: BatchFindByIdDescriptor[];
};
export declare const batchFindByIds: (ctx: Context, items: BatchFindByIdDescriptor[], options?: {
    consistentReadTableNames?: string[] | undefined;
} | undefined) => Promise<BatchFindByIdsResponse>;
