import { DocumentWithId } from '../base/common';
import { Context } from '../context';
/**
 * A replace (PutItem) request to perform with
 * [[batchReplaceDelete]].
 *
 * Performs the equivalent operation as [[replace]],
 * which is a full insert or update on the primary
 * key of the document.
 */
export declare type BatchReplaceDescriptor = {
    /** The root or child collection */
    collection: string;
    /** The operation to perform (always `'replace'`) */
    op: 'replace';
    /** The document of the item to be replaced */
    replaceItem: DocumentWithId;
};
/**
 * A replace (DeleteItem) request to perform with
 * [[batchReplaceDelete]].
 *
 * Performs the equivalent operation as [[deleteById]]/[[deleteChildById][,
 * which is a full delete on the primary key of a document
 */
export declare type BatchDeleteDescriptor = {
    /** The root or child collection */
    collection: string;
    /** The operation to perform */
    op: 'delete';
    /** The item identifier */
    id: string;
    /**
     * For child items, this is the parent object identifier
     * (mandatory for root
     * items, left blank for child items).
     */
    parentId?: string;
};
/**
 * A replace (PutItem) or delete (DeleteItem) request
 * to perform with [[batchReplaceDelete]]
 */
export declare type BatchReplaceDeleteDescriptor = BatchReplaceDescriptor | BatchDeleteDescriptor;
export declare type BatchReplaceDeleteResponse = {
    unprocessedDescriptors: BatchReplaceDeleteDescriptor[];
};
export declare const batchReplaceDelete: (ctx: Context, descriptors: BatchReplaceDeleteDescriptor[]) => Promise<BatchReplaceDeleteResponse>;
