import { Context } from '../context';
import { DocumentWithId } from '../base/common';
import { CompositeCondition } from '../base/conditions';
/**
 * Delete a child object using its `_id` field and its parents `_id`.
 *
 * @param context the context object
 * @param collectionName the name of the collection
 * @param id the child object to remove
 * @param rootObjectId the parent object id
 * @param options options to change behaviour of DynamoDB
 * @param options.condition a condition expression blocking the delete operation
 * @returns the deleted object (as stored in the database), or
 * `undefined` if not found
 * @throws {CollectionNotFoundException} when the collection is not found in the context
 */
export declare function deleteChildById<DocumentType extends DocumentWithId>(context: Context, collectionName: string, id: string, rootObjectId: string, options?: {
    condition?: CompositeCondition;
}): Promise<DocumentType | undefined>;
