import { Context } from '../context';
import { DocumentWithId } from '../base/common';
/**
 * Retrieve a child item by its `_id` field and its parent `_id`.
 *
 * Child objects can only be directly retrieved with both the parent
 * and child _id. This limitation allows them to be stored without
 * an extra index, and enables the `findChildren` method to retrieve
 * all the children of a root object in the same call.
 *
 * @param context the context object
 * @param collectionName name of the collection to search
 * @param id the `_id` value
 * @param rootObjectId the _id of the root object
 * @returns the stored value, or `undefined` if not found
 * @throws {CollectionNotFoundException} when the collection is not found in the context
 */
export declare function findChildById<DocumentType extends DocumentWithId>(context: Context, collectionName: string, id: string, rootObjectId: string): Promise<DocumentType | undefined>;
