import { Context } from '../context';
import { DocumentWithId } from '../base/common';
import { CompositeCondition } from '../base/conditions';
/**
 * Insert or replace a value in a collection.
 *
 * This operation differs from [[insert]] in that it does not check for the existence
 * of a document with the same `_id` value - it will replace whatever is there.
 *
 * @param context the context
 * @param collectionName the collection to update
 * @param value the document to insert or replace
 * @param options options to apply
 * @param options.condition an optional conditional expression that must be satifisfied for the update to proceed
 * @returns the inserted / replaced value
 * @throws {CollectionNotFoundException} when the collection is not found
 */
export declare function replace<DocumentType extends DocumentWithId>(context: Context, collectionName: string, value: Record<string, any>, options?: {
    condition?: CompositeCondition;
}): Promise<DocumentType>;
